@@ -14,15 +14,18 @@ def files_exist(self):
         If these files are not found then this cannot be a Nextflow pipeline and something has gone badly wrong.
         All lint tests are stopped immediately with a critical error message.
 
-    Files that **must** be present::
+    Files that *must* be present:
+
+    .. code-block:: bash
 
         .gitattributes
+        .gitignore
+        .markdownlint.yml
         .github/.dockstore.yml
         .github/CONTRIBUTING.md
         .github/ISSUE_TEMPLATE/bug_report.md
         .github/ISSUE_TEMPLATE/config.yml
         .github/ISSUE_TEMPLATE/feature_request.md
-        .github/markdownlint.yml
         .github/PULL_REQUEST_TEMPLATE.md
         .github/workflows/branch.yml
         .github/workflows/ci.yml
@@ -33,41 +36,54 @@ def files_exist(self):
         assets/email_template.txt
         assets/nf-core-PIPELINE_logo.png
         assets/sendmail_template.txt
-        bin/markdown_to_html.py
+        bin/scrape_software_versions.py
+        conf/modules.config
+        conf/test.config
+        conf/test_full.config
         CHANGELOG.md
-        CODE_OF_CONDUCT.md
+        CITATIONS.md
         CODE_OF_CONDUCT.md
         docs/images/nf-core-PIPELINE_logo.png
         docs/output.md
         docs/README.md
-        docs/README.md
         docs/usage.md
         lib/nfcore_external_java_deps.jar
         lib/NfcoreSchema.groovy
+        lib/NfcoreTemplate.groovy
+        lib/Utils.groovy
+        lib/WorkflowMain.groovy
+        modules/local/get_software_versions.nf
         nextflow_schema.json
         nextflow.config
         README.md
 
-    Files that *should* be present::
+    Files that *should* be present:
 
-        'main.nf',
-        'environment.yml',
-        'Dockerfile',
-        'conf/base.config',
-        '.github/workflows/awstest.yml',
-        '.github/workflows/awsfulltest.yml'
+    .. code-block:: bash
 
-    Files that *must not* be present::
+        main.nf
+        assets/multiqc_config.yaml
+        conf/base.config
+        conf/igenomes.config
+        .github/workflows/awstest.yml
+        .github/workflows/awsfulltest.yml
+        lib/WorkflowPIPELINE.groovy
 
-        'Singularity',
-        'parameters.settings.json',
-        'bin/markdown_to_html.r',
-        'conf/aws.config',
-        '.github/workflows/push_dockerhub.yml'
+    Files that *must not* be present:
 
-    Files that *should not* be present::
+    .. code-block:: bash
 
-        '.travis.yml'
+        Singularity
+        parameters.settings.json
+        bin/markdown_to_html.r
+        conf/aws.config
+        .github/workflows/push_dockerhub.yml
+
+    Files that *should not* be present:
+
+    .. code-block:: bash
+
+        .travis.yml
     """
 
     passed = []
@@ -77,10 +93,14 @@ def files_exist(self):
 
     # NB: Should all be files, not directories
     # List of lists. Passes if any of the files in the sublist are found.
+    #: test autodoc
     short_name = self.nf_config["manifest.name"].strip("\"'").replace("nf-core/", "")
     files_fail = [
         [".gitattributes"],
+        [".gitignore"],
+        [".markdownlint.yml"],
         ["CHANGELOG.md"],
+        ["CITATIONS.md"],
         ["CODE_OF_CONDUCT.md"],
         ["CODE_OF_CONDUCT.md"],
         ["LICENSE", "LICENSE.md", "LICENCE", "LICENCE.md"],  # NB: British / American spelling
@@ -92,7 +112,6 @@ def files_exist(self):
         [os.path.join(".github", "ISSUE_TEMPLATE", "bug_report.md")],
         [os.path.join(".github", "ISSUE_TEMPLATE", "config.yml")],
         [os.path.join(".github", "ISSUE_TEMPLATE", "feature_request.md")],
-        [os.path.join(".github", "markdownlint.yml")],
         [os.path.join(".github", "PULL_REQUEST_TEMPLATE.md")],
         [os.path.join(".github", "workflows", "branch.yml")],
         [os.path.join(".github", "workflows", "ci.yml")],
@@ -102,7 +121,10 @@ def files_exist(self):
         [os.path.join("assets", "email_template.txt")],
         [os.path.join("assets", "sendmail_template.txt")],
         [os.path.join("assets", f"nf-core-{short_name}_logo.png")],
-        [os.path.join("bin", "markdown_to_html.py")],
+        [os.path.join("bin", "scrape_software_versions.py")],
+        [os.path.join("conf", "modules.config")],
+        [os.path.join("conf", "test.config")],
+        [os.path.join("conf", "test_full.config")],
         [os.path.join("docs", "images", f"nf-core-{short_name}_logo.png")],
         [os.path.join("docs", "output.md")],
         [os.path.join("docs", "README.md")],
@@ -110,14 +132,21 @@ def files_exist(self):
         [os.path.join("docs", "usage.md")],
         [os.path.join("lib", "nfcore_external_java_deps.jar")],
         [os.path.join("lib", "NfcoreSchema.groovy")],
+        [os.path.join("lib", "NfcoreTemplate.groovy")],
+        [os.path.join("lib", "Utils.groovy")],
+        [os.path.join("lib", "WorkflowMain.groovy")],
+        [os.path.join("modules", "local", "get_software_versions.nf")],
     ]
+
     files_warn = [
         ["main.nf"],
-        ["environment.yml"],
-        ["Dockerfile"],
+        [os.path.join("assets", "multiqc_config.yaml")],
         [os.path.join("conf", "base.config")],
+        [os.path.join("conf", "igenomes.config")],
         [os.path.join(".github", "workflows", "awstest.yml")],
         [os.path.join(".github", "workflows", "awsfulltest.yml")],
+        [os.path.join("lib", f"Workflow{short_name[0].upper()}{short_name[1:]}.groovy")],
+        ["modules.json"],
     ]
 
     # List of strings. Fails / warns if any of the strings exist.
